Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(87)

Unified Diff: runtime/bin/http.dart

Issue 10533078: Enable standalone/io/http_test, splitting it into three separate tests. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tests/standalone/io/http_advanced_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/http.dart
diff --git a/runtime/bin/http.dart b/runtime/bin/http.dart
index 5e2f45e16b6e2e0fb963c3a9d111649efaf334c6..6fccc6dbc55ade14780c418460d67d3ebbd28545 100644
--- a/runtime/bin/http.dart
+++ b/runtime/bin/http.dart
@@ -717,11 +717,11 @@ interface HttpClientConnection {
* Set this property to [:true:] if this connection should
* automatically follow redirects. The default is [:true:].
*/
- bool followRedirect;
+ bool followRedirects;
/**
* Set this property to the maximum number of redirects to follow
* when [followRedirect] is [:true:]. If this number is exceeded the
* [onError] callback will be called with a [RedirectLimitExceeded]
* exception. The default value is 5.
*/
@@ -775,6 +775,13 @@ interface HttpClientRequest default _HttpClientRequest {
List<Cookie> get cookies();
/**
+ * Sets the requested persistent connection state.
Søren Gjesse 2012/06/11 13:19:06 Sets -> Gets and sets We should not mention HTTP
+ * The default value is the default for the protocol:
+ * true for HTTP 1.1, false for HTTP 1.0.
+ */
+ bool persistentConnection;
+
+ /**
* Returns the output stream for the request. This is used to write
* the request data. When all request data has been written close
* the stream to indicate the end of the request.
@@ -808,6 +815,11 @@ interface HttpClientResponse default _HttpClientResponse {
int get contentLength();
/**
+ * Gets the persistent connection state returned by the server.
Søren Gjesse 2012/06/11 13:19:06 I think we should make this a getter. I know the i
+ */
+ bool persistentConnection;
+
+ /**
* Returns whether the status code is one of the normal redirect
* codes [:HttpStatus.MOVED_PERMANENTLY:], [:HttpStatus.FOUND:],
* [:HttpStatus.MOVED_TEMPORARILY:], [:HttpStatus.SEE_OTHER:] and
@@ -717,11 +717,11 @@ interface HttpClientConnection {
/**
* Set this property to the maximum number of redirects to follow
- * when [followRedirect] is [:true:]. If this number is exceeded the
+ * when [followRedirects] is [:true:]. If this number is exceeded the
* [onError] callback will be called with a [RedirectLimitExceeded]
* exception. The default value is 5.
« no previous file with comments | « no previous file | tests/standalone/io/http_advanced_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698